@@ -13,10 +13,10 @@
 ##############################################################################
 """Generation-browser tests
 
-$Id: tests.py 95085 2009-01-27 08:43:42Z icemac $
+$Id: tests.py 115808 2010-08-19 19:23:02Z icemac $
 """
 import unittest
-from zope.testing.doctestunit import DocTestSuite
+import doctest
 from zope.app.generations.testing import GenerationsLayer
 from zope.app.testing import ztapi, functional
 from zope.app.generations.generations import SchemaManager, generations_key
@@ -82,8 +82,8 @@ class TestDatabaseSchema(functional.BrowserTestCase):
 def test_suite():
     TestDatabaseSchema.layer = GenerationsLayer
     return unittest.TestSuite((
-        DocTestSuite('zope.app.generations.browser.managers'),
-        DocTestSuite('zope.app.generations.browser.managerdetails'),
+        doctest.DocTestSuite('zope.app.generations.browser.managers'),
+        doctest.DocTestSuite('zope.app.generations.browser.managerdetails'),
         unittest.makeSuite(TestDatabaseSchema),
         ))
 
