@@ -11,9 +11,9 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""zope.app.zptpage common test related classes/functions/objects.
+"""zope.app.generations common test related classes/functions/objects.
 
-$Id: testing.py 72390 2007-02-06 06:28:05Z baijum $
+$Id: testing.py 116409 2010-09-14 14:49:52Z icemac $
 """
 
 __docformat__ = "reStructuredText"
