@@ -13,12 +13,12 @@
 ##############################################################################
 """Schema-generation tests
 
-$Id: tests.py 92892 2008-11-12 18:27:14Z ctheune $
+$Id: tests.py 115808 2010-08-19 19:23:02Z icemac $
 """
 
-import unittest
-from zope.testing import doctest
 from zope.app.testing import placelesssetup
+import doctest
+import unittest
 
 
 def tearDownREADME(test):
